
package App::Asciio ;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------

sub display_popup_menu
{
}

#------------------------------------------------------------------------------------------------------

1 ;
